nx.graphic.Topology.Config - Next UI Toolkit

#

API Docs for: trial
Show: Inherited Protected Private Deprecated

# nx.graphic.Topology.Config Class

Module: nx.graphic.Topology

Topology's base config

- Index
- Properties

## Item Index

### Properties

- showNavigation
- status
- theme
- viewSettingPanel

## Properties

### `showNavigation`

Boolean

Set the navigation visibility

### `status`

String

Topology status, it could be initializing/appended/ready

### `theme`

String

topology's theme, it could be blue/green/dark/slate/yellow

### `viewSettingPanel`

nx.ui.Component

Get the setting panel component instance for extend user setting